@@ -7,13 +7,7 @@ use Image::Info qw/image_type/;
 use Image::Resize;
 use List::Util qw/min max/;
 
-=head1 NAME
-
-Catalyst::View::GD::Thumbnail - Catalyst view to resize images for thumbnails
-
-=cut
-
-our $VERSION = '0.05';
+our $VERSION = '0.12';
 
 sub process {
   my ($self, $c) = @_;
@@ -73,31 +67,46 @@ sub process {
   $c->response->body($thumbnail);    
 }
 
+1;
+
+__END__
+
+=encoding utf8
+
+=head1 NAME
+
+Catalyst::View::GD::Thumbnail - Catalyst view to resize images for thumbnails.
+
+=cut
+
 =head1 SYNOPSIS
 
     Create a thumbnail view:
 
-        script/myapp_create view Thumbnail Thumbnail
+	script/myapp_create view Thumbnail Thumbnail
 
     Then in your controller:
 
-        sub thumbnail :Local :Args(1) {
-            my ($self, $c, $image_file_path) = @_;
-        
-            $c->stash->{x}     = 100;    # Create a 100px wide thumbnail
-				
-										 #or
-					
-			$c->stash->{y}     = 100;    # Create a 100px tall thumbnail
-            $c->stash->{image} = $image_file_path;
-        
-            $c->forward('View::Thumbnail');
-        }
+	sub thumbnail :Local :Args(1) {
+ 		my ($self, $c, $image_file_path) = @_;
+
+		$c->stash->{x}     = 100;    
+		# Create a 100px wide thumbnail
+
+		#or
+
+		$c->stash->{y}     = 100;    
+		# Create a 100px tall thumbnail
+
+            	$c->stash->{image} = $image_file_path;        
+            	$c->forward('View::Thumbnail');
+	}
+
 
 =head1 DESCRIPTION
 
 Catalyst::View::GD::Thumbnail resizes images to produce thumbnails, with options to set the desired x or y
-dimensions.
+dimensions. Uses the GD image library for those who are already using something more advanced than Imager.
 
 =head2 Options
 
@@ -135,29 +144,16 @@ so it accept any image format supported by I<Image::Resize>: bmp, gif, jpeg, png
 
 Please see the L<Image::Resize> documentation for more details and installation notes.
 
-=head1 AUTHOR
-
-Nick Logan (ugexe), C<< <nik_517@yahoo.com> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-catalyst-view-thumbnail at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Catalyst-View-GD-Thumbnail>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright (C) 2010 Nick Logan (ugexe).
+Nick Logan (ugexe) <F<ug@skunkds.com>>
 
-This module is free software; you
-can redistribute it and/or modify it under the same terms
-as Perl 5.10.0. For more details, see the full text of the
-licenses in the directory LICENSES.
+=head1 LICENSE AND COPYRIGHT
 
-This module is distributed in the hope that it will be
-useful, but it is provided as is and without any express
-or implied warranties. 
-
-=cut
-
-1; # End of Catalyst::View::GD::Thumbnail
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
